﻿
main();

function main() {
	var scriptName = "business Card v1";

	with(app) {

		try {
			var myDocument = app.activeDocument;
		} catch (e) {
				alert("No active document. Please open a document.");
		
				exit(-1);
		}
		
		
		var myPref_dpi = myDocument.viewPreferences.pointsPerInch;
		var myPref_horizontalMeasurementUnits = myDocument.viewPreferences.horizontalMeasurementUnits;
		var myPref_verticalMeasurementUnits = myDocument.viewPreferences.verticalMeasurementUnits;
	
		//acquiring pages (If there is no page in the document, throw error. Just one page = front side business card)
		with(myDocument) {
	
			try {
				var businessCardFrontPage = pages[0];
		
				} catch (e) {
					alert("No first page.");
					exit(-1);
				}
		
			try {
				if (pages.length > 1) {
					var businessCardBackPage = pages[1];
				} else {
					businessCardBackPage = null;
					alert("Back page for business card was not found. Creating just face page.");
					}
		
				} catch (e) {
					alert("Back page for business card was not found. Creating just face page.");
					businessCardBackPage = null;
				}
				
		}
	
		//remember layer lock states and unlock them
		var layerLocks = new Array();
		with(myDocument) {
			for (var i = 0; i < layers.length; i++) {
				layerLocks.push(layers[i].locked);
				layers[i].locked = false;
				}
		}
	
		//remember object lock states and unlock them
		var objectLocks = new Array();
		with(myDocument) {
			for (var i = 0; i < allPageItems.length; i ++) {
				objectLocks.push(allPageItems[i].locked);
				allPageItems[i].locked = false;
				}
			}
		
		var businessCardDialog = dialogs.add();
		
		businessCardDialog.name = "Business Card copy script v1";
		with(businessCardDialog.dialogColumns.add()) {
			
			
			//resize options
			with(dialogRows.add()) {
			var myGL_resizingOptionCheckbox = enablingGroups.add({staticLabel:"Resize", checkedState: true});
			//myGL_resizingOptionCheckbox.dialogColumns.add();
			var myGL_resizeRadioGroup = myGL_resizingOptionCheckbox.dialogColumns.add().radiobuttonGroups.add();
			var myGL_resizeProportionallyRadioButton = myGL_resizeRadioGroup.radiobuttonControls.add({staticLabel: "Resize proportionally", checkedState:true, minWidth: 160});
			var myGL_stretchToFitRadioButton = myGL_resizeRadioGroup.radiobuttonControls.add({staticLabel: "Stretch to fit", checkedState:false, minWidth: 160});
			// if size is ok, disable resizing option
			if (isSizeOk(businessCardFrontPage,myPref_horizontalMeasurementUnits,myPref_verticalMeasurementUnits, myPref_dpi) ) {
					myGL_resizingOptionCheckbox.checkedState = false;
				} 
			
			}
			
		
			with(dialogRows.add()) {
			//number of copies option
			var myGL_customNumberOfCopiesCheckButton = enablingGroups.add({staticLabel:"Custom number of copies", checkedState: false, minWidth: 160});
			//myGL_customNumberOfCopiesCheckButton.dialogColumns.add();
			var myGL_numberOfCopiesDropDown = myGL_customNumberOfCopiesCheckButton.dialogColumns.add().dropdowns.add({stringList: ["1", "2", "3", "4", "5", "6", "7", "8", "9", "10"], minWidth:200});
			}
		
			
		}
	
		
		//if clicked on cancel, exit
		if (!businessCardDialog.show()) {
			exit(0);
			}
		
		//set number of copies
		var numberOfCopies;
		if (myGL_customNumberOfCopiesCheckButton.checkedState == false) {
			numberOfCopies = 9;
			} else {
				numberOfCopies =  myGL_numberOfCopiesDropDown.selectedIndex;
				}
			
		//resizing options
		var resize = myGL_resizingOptionCheckbox.checkedState;
		var proportionalResizing = myGL_resizeProportionallyRadioButton.checkedState;
	
		
		//checking size for business card
		checkSizeAndResize(businessCardFrontPage,myPref_horizontalMeasurementUnits,myPref_verticalMeasurementUnits,myPref_dpi,proportionalResizing,resize);
			
		if (businessCardBackPage!=null) {
			checkSizeAndResize(businessCardBackPage,myPref_horizontalMeasurementUnits,myPref_verticalMeasurementUnits,myPref_dpi,proportionalResizing,resize);
		}
		
		
		//creating a new page for frontsides
		var newFrontPage = createNewPage(myDocument, myPref_dpi);
	
		copybusinessCardToPage(businessCardFrontPage, newFrontPage, numberOfCopies,
			myPref_horizontalMeasurementUnits,myPref_verticalMeasurementUnits,myPref_dpi);
		
		//creating a new page for backsides
		if (businessCardBackPage != null) {
			
			var newBackPage = createNewPage(myDocument, myPref_dpi);
	
			copybusinessCardToPage(businessCardBackPage, newBackPage,numberOfCopies,
				myPref_horizontalMeasurementUnits,myPref_verticalMeasurementUnits,myPref_dpi);
		}
		
		//restore object locks
		with(myDocument) {
			for (var i = objectLocks.length-1; i >= 0 ; i --) {
				allPageItems[i].locked = objectLocks.pop();
				}
			}
		
		//restore layer locks
		for (var i = myDocument.layers.length-1; i >= 0 ; i--) {
			myDocument.layers[i].locked = layerLocks.pop();
			}
		
		businessCardDialog.destroy();
		
		exit(0);
	
	}
}

function isSizeOk(_page,_horizontalUnits, _verticalUnits, _dpi) {
	var bounds = _page.bounds;
	
	//actual demansions in inches
	var actualPageWidth = convertUnitsToInches(_horizontalUnits,bounds[3] - bounds[1],_dpi);
	var actualPageHeight = convertUnitsToInches(_verticalUnits,bounds[2] - bounds[0],_dpi);
	
	//demanded demansions in inches
	var demandedWidth = 3.5;
	var demandedHeight = 2;
	
	if (demandedWidth < actualPageWidth || demandedHeight < actualPageHeight) {
		return false;
		}
	return true;
	
	}

function convertInchesToCorrectUnits(_unitType, _num, _dpi) {
	switch(_unitType) {
		case MeasurementUnits.AGATES:
			return _num*14;
			break;
		case MeasurementUnits.CENTIMETERS:
			return _num*2.54;
			break;
		case MeasurementUnits.CICEROS:
			return (1/0.17717)*_num;
			break;
		case MeasurementUnits.CUSTOM:
			alert("Cannot convert from custom measurement units");
			break;
		case MeasurementUnits.INCHES:
			return _num;
			break;
		case MeasurementUnits.INCHES_DECIMAL:
			return _num;
			break;
		case MeasurementUnits.MILLIMETERS:
			return _num*25.4;
			break;
		case MeasurementUnits.PICAS:
			return _num*6*_dpi/72;
			break;
		case MeasurementUnits.POINTS:
			return _num*_dpi;
			break;
		default:
			alert("error, undefined type of measurement units");
			return null;
			break;
		}
	}

/**
  * Converts units to inches
  */
function convertUnitsToInches(_unitType, _num,_dpi) {
	
	switch(_unitType) {
		case MeasurementUnits.AGATES:
			return _num/14;
			break;
		case MeasurementUnits.CENTIMETERS:
			return _num/2.54;
			break;
		case MeasurementUnits.CICEROS:
			return 0.17717*_num;
			break;
		case MeasurementUnits.CUSTOM:
			alert("Cannot convert from custom measurement units");
			break;
		case MeasurementUnits.INCHES:
			return _num;
			break;
		case MeasurementUnits.INCHES_DECIMAL:
			return _num;
			break;
		case MeasurementUnits.MILLIMETERS:
			return _num/25.4;
			break;
		case MeasurementUnits.PICAS:
			return _num/6 *_dpi/72;
			break;
		case MeasurementUnits.POINTS:
			return _num/_dpi;
			break;
		default:
			alert("error, undefined type of measurement units");
			break;
		}
	
		
	}

function copybusinessCardToPage(businessCardPage, _newPage, numberOfCopies, _horizontalUnits, _verticalUnits,_dpi)  {
		var arrayOfPageItems = businessCardPage.pageItems;
		
		var page_x = _newPage.bounds[1];
		var page_y = _newPage.bounds[0];
		
		var help;
		var x1, y1;
		
		var x_offset = convertInchesToCorrectUnits(_horizontalUnits, 3.5,_dpi);
		var y_offset = convertInchesToCorrectUnits(_verticalUnits, 2,_dpi);
		
		var x_page_offset = page_x + convertInchesToCorrectUnits(_horizontalUnits, 0.75,_dpi);
		var y_page_offset = page_y + convertInchesToCorrectUnits(_verticalUnits, 0.5,_dpi);
		
		for (var j = 0; j <2; j++) {
			
			for (var k = 0; k<5; k++) {
				
				//I need to go through the array from back to keep the overlaying order
				for (var i = arrayOfPageItems.length-1; i >=0; i--) {
					help = arrayOfPageItems[i].duplicate();
					
					x1 = x_page_offset + x_offset*j + help.geometricBounds[1];
					y1 = y_page_offset +  y_offset*k + help.geometricBounds[0];
					
			 
					help.move(_newPage);
					help.move([x1,y1]);
					
					
					}
				
					if(numberOfCopies == 0) {
							break;
						}
					numberOfCopies--;
				}
			
				if(numberOfCopies == 0) {
						break;
						}
					
					
		
		}
	}



/**
  *  Creating next page
  */
function createNewPage(myDocument, _dpi) {
/*	
	LocationOptions.AFTER Places the object after the reference object. 1634104421 = 'afte'  
	LocationOptions.AT_BEGINNING Places the object at the beginning of the containing object. 1650945639 = 'bgng'  
	LocationOptions.AT_END Places the object at the end of the containing object. 1701733408 = 'end '  
	LocationOptions.BEFORE Places the object before the reference object. 1650812527 = 'befo'  
	LocationOptions.UNKNOWN No location specified. 1433299822 = 'Unkn'  
*/

	//letter format
	var letter_width_inch = 8.5;
	var letter_height_inch = 11;

	var _newPage = myDocument.pages.add(LocationOptions.AT_END);
	//_newPage.pageAlignment = -(letter_height_inch * _dpi)/2;
	
	try {
		_newPage.resize(letter_width_inch * _dpi,letter_height_inch * _dpi);
	} catch (e) {
		alert ("Page Control is either not installed or expired. Please visit http://www.dtptools.com/ for more.", "Page Control");
		_newPage.remove();
		exit(1);
		
	}
	
	return _newPage;
	}

/**
  * Function for checking dimensions fo business card
  */
function checkSizeAndResize(_page,_horizontalUnits, _verticalUnits, _dpi,_proportional_resizing, _resize) {
	var bounds = _page.bounds;
	
	//actual demansions in inches
	var actualPageWidth = convertUnitsToInches(_horizontalUnits,bounds[3] - bounds[1],_dpi);
	var actualPageHeight = convertUnitsToInches(_verticalUnits,bounds[2] - bounds[0],_dpi);
	
	//demanded demansions in inches
	var demandedWidth = 3.5;
	var demandedHeight = 2;
	
	if (demandedWidth < actualPageWidth || demandedHeight < actualPageHeight) {
		var errorMessage = "Dimensions of your document don't meet 2 inches by 3,5 inches.";
		
		if (_resize) {
			errorMessage+= " Your document will be resized.";
			alert(errorMessage);
		} else {
			errorMessage+= " Please modify your document.";
			alert(errorMessage);
			exit(-1);
			}
		
		var newPageWidth;
		var newPageHeight;
		var ratioForTextResizing;
		
		if (_proportional_resizing) {
			//ratio between actual and demanded dimensions
			var widthRatio = actualPageWidth/demandedWidth;
			var heightRatio = actualPageHeight/demandedHeight;
			
			//demanded demansions in points
			
			
			if (widthRatio > heightRatio) {
				newPageWidth =  _dpi * actualPageWidth/widthRatio;
				newPageHeight =  _dpi * actualPageHeight/widthRatio;
				
				ratioForTextResizing = widthRatio;
				} else 
			{
				newPageWidth =  _dpi * actualPageWidth/heightRatio;
				newPageHeight =  _dpi * actualPageHeight/heightRatio;
				
				ratioForTextResizing = heightRatio;
				}
			
		} else {
			newPageWidth = _dpi * demandedWidth;
			newPageHeight = _dpi * demandedHeight;
			
			ratioForTextResizing=Math.max(actualPageHeight,demandedHeight);
			}
		myResizeText(_page, ratioForTextResizing) ;
		
		try {
			_page.resize(newPageWidth,newPageHeight,"0", ContentAnchor.topLeftContentAnchor, ScalePageContent.scaleToPage);
		} catch (e) {
			alert ("Page Control is either not installed or expired. Please visit http://www.dtptools.com/ for more.", "Page Control");
			exit(1);
		}
		
		myResizePictures(_page);
		
		return true; 
		}
	
	return true;
	
	}

function myResizeText(_page, _ratioForTextResizing) {
	
	for (var i=0; i < _page.textFrames.length; i++) {
			for (var j = 0; j < _page.textFrames[i].characters.length; j ++) {
					 _page.textFrames[i].characters[j].pointSize =_page.textFrames[i].characters[j].pointSize/_ratioForTextResizing;
					 
				}
		}
	
	}

function myResizePictures(_page) {
	//every  picture frame is already resized by PageControl - we just need to fit the images
	for (var i=0; i < _page.allGraphics.length; i++) {
			_page.allGraphics[i].fit(FitOptions.CONTENT_TO_FRAME);
		}
	}





